@@ -8,7 +8,7 @@ from blueflask.lib.infos import no_content
 from ...db import connexion
 from ...channel import Channel
 from ...program import ProgramGuide
-from ...consts import DB_CREDENTIALS, LOGS, CACHE, CATEGORIE
+from ...consts import DB_CREDENTIALS, LOGS, CACHE, CATEGORIE, CHANNEL_LIST
 from . import api
 
 import datetime
@@ -29,7 +29,7 @@ def categories():
 
 @api.route('/channels', methods=['GET'])
 def all_channel():
-    return jsonify(CACHE)
+    return jsonify(CHANNEL_LIST)
 
 
 @api.route('/channels/categories', methods=['GET'])
